{# django-messages-to-bootstrap-notify #}
{# dm2bn/templates/dm2bn/includes/dm2bn_static.html #}

{% load static %}

{# css #}
<link href="{% static "m2bn/vendor/bootstrap/css/bootstrap.min.css" %}" rel="stylesheet" media="screen">
<link href="{% static "m2bn/vendor/font-awesome/css/font-awesome.min.css" %}" rel="stylesheet" media="screen">

{# js #}
<script type="text/javascript" src="{% static "dm2bn/vendor/jquery/jquery-3.2.1.min.js" %}"></script>
<script type="text/javascript" src="{% static "dm2bn/vendor/bootstrap/js/bootstrap.min.js" %}"></script>
<script type="text/javascript" src="{% static "dm2bn/vendor/bootstrap-notify/bootstrap-notify.min.js" %}"></script>
<script type="text/javascript" src="{% static "dm2bn/vendor/striptags/striptags.js" %}"></script>
<script type="text/javascript" src="{% static "dm2bn/vendor/underscore/underscore-min.js" %}"></script>
<script type="text/javascript" src="{% static "dm2bn/vendor/bootstrap-notify-simple-wrapper/bootstrap-notify-simple-wrapper.min.js" %}"></script>
