# -*- coding: utf-8 -*-

# django-messages-to-bootstrap-notify
# dm2bn/__init__.py

from __future__ import unicode_literals


__all__ = [
    "default_app_config",
]


default_app_config = "dm2bn.apps.Config"
