{# django-messages-to-bootstrap-notify #}
{# dm2bn/templates/dm2bn/templatetags/dm2bn_settings.html #}

<script type="text/javascript">
    // dm2bn settings
    var messagesCumulativeDelay = {{ MESSAGES_CUMULATIVE_DELAY }},
        messageDelay = {{ MESSAGE_DELAY }},
        messageDelayFactor = {{ MESSAGE_DELAY_FACTOR }},
        messageIcon = {{ MESSAGE_ICON }},
        messageDefaultSettings = {{ MESSAGE_DEFAULT_SETTING }};
</script>
